from django.apps import AppConfig


class DjangoBibleConfig(AppConfig):
    name = "djangobible"
